@@ -7,7 +7,7 @@
 * re-register components.
 *
 */
-#define NS_BUILD_ID 0000000000
+#define NS_BUILD_ID 2005090123
 
 /* GRE_BUILD_ID - GRE build version identifier
  *
@@ -17,7 +17,7 @@
  * GRE_BUILD_ID will just contain <milestone>. 
  *
  */
-#define GRE_BUILD_ID "1.6_0000000000"
+#define GRE_BUILD_ID "1.7.8_2005090123"
 
 #endif /* _NSBUILDID_H_ */
 
